"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withIos = void 0;
const generateCode_1 = require("@expo/config-plugins/build/utils/generateCode");
const config_plugins_1 = require("expo/config-plugins");
const fs_1 = require("fs");
const path_1 = require("path");
const copyFolderRecursiveSync_1 = __importDefault(require("./utils/copyFolderRecursiveSync"));
const MICROPHONE_USAGE = "Allow $(PRODUCT_NAME) to access your microphone";
const sources = `
source 'https://github.com/Banuba/specs.git'
source 'https://github.com/CocoaPods/Specs.git'
source 'https://github.com/sdk-banuba/banuba-sdk-podspecs.git'
\n
`;
const withSource = (config) => {
    return (0, config_plugins_1.withDangerousMod)(config, [
        "ios",
        (modConfig) => {
            if (modConfig.modRequest.platform === "ios") {
                const { platformProjectRoot } = modConfig.modRequest;
                const podfile = (0, path_1.resolve)(platformProjectRoot, "Podfile");
                const contents = (0, fs_1.readFileSync)(podfile, "utf-8");
                const newContent = sources;
                const tag = "expo-banuba-source";
                const header = (0, generateCode_1.createGeneratedHeaderComment)(newContent, tag, "#");
                if (!contents.includes(header)) {
                    const mergedSource = (0, generateCode_1.mergeContents)({
                        tag,
                        src: contents,
                        newSrc: newContent,
                        anchor: "flipper_config = FlipperConfiguration.disabled",
                        offset: 0,
                        comment: "#",
                    });
                    (0, fs_1.writeFileSync)(podfile, mergedSource.contents);
                }
            }
            return modConfig;
        },
    ]);
};
const withAssets = (config, assetsPath) => {
    return (0, config_plugins_1.withXcodeProject)(config, (modConfig) => {
        const sourceRoot = config_plugins_1.IOSConfig.Paths.getSourceRoot(modConfig.modRequest.projectRoot);
        const projectName = modConfig.modRequest.projectName;
        const paths = [
            {
                source: (0, path_1.join)(assetsPath, "Assets.xcassets"),
                destination: (0, path_1.join)(sourceRoot, "Assets.xcassets"),
            },
            {
                source: (0, path_1.join)(assetsPath, "luts"),
                destination: (0, path_1.join)(sourceRoot, "luts"),
            },
            {
                source: (0, path_1.join)(assetsPath, "en.lproj"),
                destination: (0, path_1.join)(sourceRoot, "en.lproj"),
            },
        ];
        for (const { source, destination } of paths) {
            const fileName = (0, path_1.basename)(source);
            if (!(0, fs_1.existsSync)(destination)) {
                (0, fs_1.mkdirSync)(destination);
            }
            (0, copyFolderRecursiveSync_1.default)(source, destination);
            if (!modConfig.modResults.hasFile(`${projectName}/${fileName}`)) {
                modConfig.modResults = config_plugins_1.IOSConfig.XcodeUtils.addResourceFileToGroup({
                    filepath: `${projectName}/${fileName}`,
                    groupName: projectName,
                    isBuildFile: true,
                    project: modConfig.modResults,
                });
            }
        }
        return modConfig;
    });
};
const withPermissions = (config) => {
    return (0, config_plugins_1.withInfoPlist)(config, (modConfig) => {
        modConfig.modResults.NSMicrophoneUsageDescription =
            modConfig.modResults.NSMicrophoneUsageDescription || MICROPHONE_USAGE;
        modConfig.modResults.NSCameraUsageDescription =
            modConfig.modResults.NSCameraUsageDescription ||
                "Allow $(PRODUCT_NAME) to access your camera";
        modConfig.modResults.NSPhotoLibraryUsageDescription =
            modConfig.modResults.NSPhotoLibraryUsageDescription ||
                "Allow $(PRODUCT_NAME) to access your photo library";
        return modConfig;
    });
};
const withIos = (config, iosProps) => {
    config = withSource(config);
    config = withAssets(config, iosProps.assetsPath);
    config = withPermissions(config);
    return config;
};
exports.withIos = withIos;
